# Changelog

## 0.1.1 (2022-11-05)

### Changes

-   Added [documentation](https://font-awesome-flask.readthedocs.io/en/stable/)

## 0.1.0 (2022-10-27)

### Changes

-   Initial release of `Font-Awesome-Flask`
